﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Linq;
using System.Web;
using Semiodesk.Trinity;

namespace Semiodesk.Examples.WebApp.Models
{
    public static class StoreFactory
    {
        public static IStore GetStore()
        {
            var connectionString = ConfigurationManager.ConnectionStrings["GraphDb"];
            if( connectionString != null )
            {
                return Semiodesk.Trinity.StoreFactory.CreateStore(connectionString.ConnectionString);
            }
            return null;
        }

        private static Uri GetDefaultModelUri()
        {
            string defaultModelName = ConfigurationManager.AppSettings["DefaultModel"];
            Uri defaultModelUri = new Uri(defaultModelName);

            return defaultModelUri;
        }

        

        public static IModel GetModel(IStore store = null, Uri modelUri = null)
        {
            if (modelUri == null)
            {
                modelUri = GetDefaultModelUri();
            }

            if (store == null)
                store = GetStore();

            if (store.ContainsModel(modelUri))
            {
                return store.GetModel(modelUri);
            }
            else
            {
                return store.CreateModel(modelUri);
            }
        }

    }
}